pub struct BatteryConfigureWatchRequest {
pub options: WatchOptions,
}Fields
options: WatchOptionsTrait Implementations
Sourceimpl Clone for BatteryConfigureWatchRequest
impl Clone for BatteryConfigureWatchRequest
Sourcefn clone(&self) -> BatteryConfigureWatchRequest
fn clone(&self) -> BatteryConfigureWatchRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BatteryConfigureWatchRequest
impl Debug for BatteryConfigureWatchRequest
Sourceimpl<D: ResourceDialect> Decode<BatteryConfigureWatchRequest, D> for BatteryConfigureWatchRequest
impl<D: ResourceDialect> Decode<BatteryConfigureWatchRequest, D> for BatteryConfigureWatchRequest
Sourceimpl<D: ResourceDialect> Encode<BatteryConfigureWatchRequest, D> for &BatteryConfigureWatchRequest
impl<D: ResourceDialect> Encode<BatteryConfigureWatchRequest, D> for &BatteryConfigureWatchRequest
Sourceimpl<D: ResourceDialect, T0: Encode<WatchOptions, D>> Encode<BatteryConfigureWatchRequest, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<WatchOptions, D>> Encode<BatteryConfigureWatchRequest, D> for (T0,)
impl Persistable for BatteryConfigureWatchRequest
impl StructuralPartialEq for BatteryConfigureWatchRequest
Sourceimpl TypeMarker for BatteryConfigureWatchRequest
impl TypeMarker for BatteryConfigureWatchRequest
Sourcetype Owned = BatteryConfigureWatchRequest
type Owned = BatteryConfigureWatchRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for BatteryConfigureWatchRequest
impl ValueTypeMarker for BatteryConfigureWatchRequest
Sourcetype Borrowed<'a> = &'a BatteryConfigureWatchRequest
type Borrowed<'a> = &'a BatteryConfigureWatchRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for BatteryConfigureWatchRequest
impl RefUnwindSafe for BatteryConfigureWatchRequest
impl Send for BatteryConfigureWatchRequest
impl Sync for BatteryConfigureWatchRequest
impl Unpin for BatteryConfigureWatchRequest
impl UnsafeUnpin for BatteryConfigureWatchRequest
impl UnwindSafe for BatteryConfigureWatchRequest