pub struct BatteryConfigureWatchResponse {
pub effective_options: WatchOptions,
}Fields
effective_options: WatchOptionsTrait Implementations
Sourceimpl Clone for BatteryConfigureWatchResponse
impl Clone for BatteryConfigureWatchResponse
Sourcefn clone(&self) -> BatteryConfigureWatchResponse
fn clone(&self) -> BatteryConfigureWatchResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D: ResourceDialect> Decode<BatteryConfigureWatchResponse, D> for BatteryConfigureWatchResponse
impl<D: ResourceDialect> Decode<BatteryConfigureWatchResponse, D> for BatteryConfigureWatchResponse
Sourceimpl<D: ResourceDialect> Encode<BatteryConfigureWatchResponse, D> for &BatteryConfigureWatchResponse
impl<D: ResourceDialect> Encode<BatteryConfigureWatchResponse, D> for &BatteryConfigureWatchResponse
Sourceimpl<D: ResourceDialect, T0: Encode<WatchOptions, D>> Encode<BatteryConfigureWatchResponse, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<WatchOptions, D>> Encode<BatteryConfigureWatchResponse, D> for (T0,)
impl Persistable for BatteryConfigureWatchResponse
impl StructuralPartialEq for BatteryConfigureWatchResponse
Sourceimpl TypeMarker for BatteryConfigureWatchResponse
impl TypeMarker for BatteryConfigureWatchResponse
Sourcetype Owned = BatteryConfigureWatchResponse
type Owned = BatteryConfigureWatchResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for BatteryConfigureWatchResponse
impl ValueTypeMarker for BatteryConfigureWatchResponse
Sourcetype Borrowed<'a> = &'a BatteryConfigureWatchResponse
type Borrowed<'a> = &'a BatteryConfigureWatchResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for BatteryConfigureWatchResponse
impl RefUnwindSafe for BatteryConfigureWatchResponse
impl Send for BatteryConfigureWatchResponse
impl Sync for BatteryConfigureWatchResponse
impl Unpin for BatteryConfigureWatchResponse
impl UnsafeUnpin for BatteryConfigureWatchResponse
impl UnwindSafe for BatteryConfigureWatchResponse